16.95. cdist-type__package_emerge_dependencies(7) — cdist 6.1.1 documentation

# 16.95. cdist-type__package_emerge_dependencies(7)

## 16.95.1. NAME

cdist-type__package_emerge_dependencies - Install dependencies for __package_emerge

## 16.95.2. DESCRIPTION

Portage is usually used on the gentoo distribution to manage packages. This type installs the following tools which are required by __package_emerge to work:

- app-portage/flaggie
- app-portage/gentoolkit

## 16.95.3. REQUIRED PARAMETERS

None

## 16.95.4. OPTIONAL PARAMETERS

None

## 16.95.5. EXAMPLES

    # Ensure app-portage/flaggie and app-portage/gentoolkit are installed
    __package_emerge_dependencies

## 16.95.6. SEE ALSO

cdist-type__package(7), cdist-type__package_emerge(7)

## 16.95.7. AUTHORS

Thomas Oettli <otho--@--sfs.biz>

## 16.95.8. COPYING

Copyright (C) 2013 Thomas Oettli. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.